@@ -15,12 +15,11 @@ import re
 from astro_ghost.PS1QueryFunctions import getcolorim, get_hosts
 from astro_ghost.hostMatching import build_ML_df
 from astro_ghost.NEDQueryFunctions import getNEDInfo
-from astropy.coordinates import Angle
 from astro_ghost.gradientAscent import gradientAscent
 from astro_ghost.starSeparation import separateStars_STRM
 from astro_ghost.sourceCleaning import clean_dict, removePS1Duplicates, getColors, makeCuts
 from astro_ghost.stellarLocus import calc_7DCD
-from astro_ghost.DLR import calc_DLR, chooseByDLR
+from astro_ghost.DLR import chooseByDLR
 import requests
 import pickle
 import os
@@ -652,42 +651,6 @@ def findNewHosts(snName, snCoord, snClass, verbose=0, starcut='gentle'):
     if verbose:
         print("Saving table of hosts to %s."%(path+"tables/FinalAssociationTable.csv"))
 
-    # re-calculate values for the SN matched by gradient ascent, to be used for classification
-    #DLR = []
-    #dist = []
-    host_DF = getColors(host_DF)
-    host_DF = calc_7DCD(host_DF)
-
-    host_DF['gApMag_gKronMag'] = host_DF['gApMag'] - host_DF['gKronMag']
-    host_DF['rApMag_rKronMag'] = host_DF['rApMag'] - host_DF['rKronMag']
-    host_DF['iApMag_iKronMag'] = host_DF['iApMag'] - host_DF['iKronMag']
-    host_DF['zApMag_zKronMag'] = host_DF['zApMag'] - host_DF['zKronMag']
-    host_DF['yApMag_yKronMag'] = host_DF['yApMag'] - host_DF['yKronMag']
-
-    for idx, row in host_DF.iterrows():
-        if row.dist != row.dist:
-            try:
-                theta = np.nan
-                #get source
-                table1 = host_DF.iloc[[idx]]
-                tempDist, R = calc_DLR(Angle(table1['TransientRA'].values[0]*u.deg),Angle(table1['TransientDEC'].values[0]*u.deg),table1['raMean'], table1['decMean'], np.float64(table1['rKronRad']), np.float64(table1['rKronRad']), table1, 'r')
-                #DLR.append(R)
-                #dist.append(tempDist[0])
-                host_DF.loc[idx, 'dist'] = tempDist[0]
-                host_DF.loc[idx, 'dist/DLR'] = R
-            except:
-                #DLR.append(1.e10)
-                #dist.append(np.nan)
-                host_DF.loc[idx, 'dist'] = np.nan
-                host_DF.loc[idx, 'dist/DLR'] = 1.e10
-    print(host_DF['dist'])
-
-    #DLR = np.array(DLR)
-    #dist = np.array(dist)
-
-    #host_DF["dist"] = dist
-    #host_DF["dist/DLR"] = DLR
-
     host_DF.to_csv(path+"FinalAssociationTable.csv", index=False)
 
     #hSpecPath = path+"/hostSpectra/"
