@@ -5,8 +5,6 @@ from astro_ghost.TNSQueryFunctions import getTNSSpectra
 from astro_ghost.NEDQueryFunctions import getNEDSpectra
 from astro_ghost.ghostHelperFunctions import *
 from astropy.coordinates import SkyCoord
-from astro_ghost.classifier import loadClassifier, preprocess_dataframe
-from sklearn import preprocessing
 from astropy import units as u
 import pandas as pd
 from datetime import datetime
@@ -32,15 +30,6 @@ snCoord = [SkyCoord(14.162*u.deg, -9.90253*u.deg, frame='icrs'), \
 # if we have no match then it manually associates them.
 hosts = getTransientHosts(snName, snCoord, verbose=verbose, starcut='normal')
 
-# classify transients
-feature_list, dataML_preprocessed, labels_df2, names = preprocess_dataframe(hosts)
-dataML_matrix_scaled = preprocessing.scale(dataML_preprocessed)
-rf = load_classifier()
-names = hosts['TransientName'].values
-class_predictions = rf.predict(dataML_matrix_scaled, labels_df2.values)
-for i in np.arange(len(class_predictions)):
-    print("%s is predicted to be a %s." % (names[i], class_predictions[i]))
-
 #create directories to store the host spectra, the transient spectra, and the postage stamps
 hSpecPath = "./hostSpectra/"
 tSpecPath = "./SNspectra/"
@@ -89,3 +78,8 @@ getHostImage(snName, save=0)
 
 # 6. Find all supernova-host galaxy matches within a certain search radius (in arcseconds)
 coneSearchPairs(supernovaCoord[0], 1.e3)
+
+#7. Beta: find photometric redshift of host galaxies matches:
+from astro_ghost.photoz_helper import calc_photoz
+hosts = calc_photoz(hosts)
+print(hosts['photo_z'].values)
